==> touhoulittlemaid-fabric-1.21.1-0.1.7.1-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/entity/layer/LayerMaidBackItem.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.layer;

import com.github.tartaricacid.touhoulittlemaid.api.entity.IMaid;
import com.github.tartaricacid.touhoulittlemaid.client.model.bedrock.BedrockModel;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.EntityMaidRenderer;
import com.github.tartaricacid.touhoulittlemaid.compat.carryon.RenderFixer;
import com.github.tartaricacid.touhoulittlemaid.compat.tacz.TacCompat;
import com.github.tartaricacid.touhoulittlemaid.entity.backpack.BackpackManager;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import net.minecraft.class_1308;
import net.minecraft.class_1799;
import net.minecraft.class_1831;
import net.minecraft.class_310;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_7833;
import net.minecraft.class_811;

public class LayerMaidBackItem extends class_3887<class_1308, BedrockModel<class_1308>> {
    private final EntityMaidRenderer renderer;

    public LayerMaidBackItem(EntityMaidRenderer renderer) {
        super(renderer);
        this.renderer = renderer;
    }

    @Override
    public void render(class_4587 matrixStack, class_4597 bufferIn, int packedLightIn, class_1308 mob, float limbSwing, float limbSwingAmount, float partialTicks, float ageInTicks, float netHeadYaw, float headPitch) {
        IMaid maid = IMaid.convert(mob);
        if (maid == null) {
            return;
        }
        class_1799 stack = maid.getBackpackShowItem();
        if (!renderer.getMainInfo().isShowBackpack() || mob.method_6113()
                || mob.method_5767() || RenderFixer.isCarryOnRender(stack, bufferIn)) {
            return;
        }
        if (maid instanceof EntityMaid entityMaid && !entityMaid.getConfigManager().isShowBackItem()) {
            return;
        }

        if (stack.method_7909() instanceof class_1831) {
            matrixStack.method_22903();
            matrixStack.method_22907(class_7833.field_40718.rotationDegrees(180.0F));
            matrixStack.method_22907(class_7833.field_40714.rotationDegrees(180.0F));
            matrixStack.method_22904(0, 0.5, -0.25);
            if (maid instanceof EntityMaid entityMaid && entityMaid.getConfigManager().isShowBackpack()) {
                maid.getMaidBackpackType().offsetBackpackItem(matrixStack);
            } else {
                BackpackManager.getEmptyBackpack().offsetBackpackItem(matrixStack);
            }
            class_310.method_1551().method_1480().method_23177(mob, stack, class_811.field_4319, false, matrixStack, bufferIn, mob.method_37908(), packedLightIn, class_4608.field_21444, mob.method_5628());
            matrixStack.method_22909();
            return;
        }

        // TAC 兼容
        TacCompat.renderBackGun(matrixStack, bufferIn, packedLightIn, stack, maid);
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.8-neo1.4.0-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/entity/layer/LayerMaidBackItem.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.layer;

import com.github.tartaricacid.touhoulittlemaid.api.entity.IMaid;
import com.github.tartaricacid.touhoulittlemaid.client.model.bedrock.BedrockModel;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.EntityMaidRenderer;
import com.github.tartaricacid.touhoulittlemaid.compat.carryon.RenderFixer;
import com.github.tartaricacid.touhoulittlemaid.compat.gun.common.GunClientUtil;
import com.github.tartaricacid.touhoulittlemaid.entity.backpack.BackpackManager;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import net.minecraft.class_1308;
import net.minecraft.class_1799;
import net.minecraft.class_1831;
import net.minecraft.class_310;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_7833;
import net.minecraft.class_811;

public class LayerMaidBackItem extends class_3887<class_1308, BedrockModel<class_1308>> {
    private final EntityMaidRenderer renderer;

    public LayerMaidBackItem(EntityMaidRenderer renderer) {
        super(renderer);
        this.renderer = renderer;
    }

    @Override
    public void render(class_4587 matrixStack, class_4597 bufferIn, int packedLightIn, class_1308 mob, float limbSwing, float limbSwingAmount, float partialTicks, float ageInTicks, float netHeadYaw, float headPitch) {
        IMaid maid = IMaid.convert(mob);
        if (maid == null) {
            return;
        }
        class_1799 stack = maid.getBackpackShowItem();
        if (!renderer.getMainInfo().isShowBackpack() || mob.method_6113()
                || mob.method_5767() || RenderFixer.isCarryOnRender(stack, bufferIn)) {
            return;
        }
        if (maid instanceof EntityMaid entityMaid && !entityMaid.getConfigManager().isShowBackItem()) {
            return;
        }

        if (stack.method_7909() instanceof class_1831) {
            matrixStack.method_22903();
            matrixStack.method_22907(class_7833.field_40718.rotationDegrees(180.0F));
            matrixStack.method_22907(class_7833.field_40714.rotationDegrees(180.0F));
            matrixStack.method_22904(0, 0.5, -0.25);
            if (maid instanceof EntityMaid entityMaid && entityMaid.getConfigManager().isShowBackpack()) {
                maid.getMaidBackpackType().offsetBackpackItem(matrixStack);
            } else {
                BackpackManager.getEmptyBackpack().offsetBackpackItem(matrixStack);
            }
            class_310.method_1551().method_1480().method_23177(mob, stack, class_811.field_4319, false, matrixStack, bufferIn, mob.method_37908(), packedLightIn, class_4608.field_21444, mob.method_5628());
            matrixStack.method_22909();
            return;
        }

        // 枪械额外渲染兼容
        GunClientUtil.renderBackGun(matrixStack, bufferIn, packedLightIn, stack, maid);
    }
}
